@@ -4,12 +4,6 @@
 
 #include <linux/time_types.h>
 
-#include <inttypes.h>
-
-struct open_how {
-	uint64_t	flags;
-	uint64_t	mode;
-	uint64_t	resolve;
-};
+#include <linux/openat2.h>
 
 #endif
